proc getCalcTime { file } {
    set fp [open $file]
    set xml [read $fp]
    close $fp
    set err [catch {dom parse $xml doc} errstring]
    set node [$doc selectNodes [format_xpath {/*/time[@n=%s]} "Total time"]]
    set total_time [get_domnode_attribute $node cpu]
    return $total_time
}

set surface_id 1
set lines_list [list 1 2 3 4]
set num_divisions [list 4 6 8 10 12 14 16]
set elems [list dkt drill_rot 6N Quadrilateral]

set check_points ""
lappend check_points {2.0 2.0 0.0 "Disp Z" {"Contour fill" Static Displacements "" Disp_Z} {Last timestep} "" ""}
lappend check_points {2.0 2.0 0.0 "Disp Z" {"Contour fill" Static Shells//Momentus "" Mx'} {Last timestep} "" ""}

set script_path [ file dirname [ file normalize [ info script ] ] ]
set f [open [file join $script_path "results.txt"] w]

foreach elem $elems {
    puts -nonewline $f "Num nodes\t"
    puts -nonewline $f "cpu_time\t"
    foreach cp $check_points {
	puts -nonewline $f "$elem\t"
    }
}

set err [catch {
	foreach num $num_divisions {
	    puts -nonewline $f "\n"
		       
	    # Run for all mesh sizes
	    foreach elem_type $elems {                
		# Set element type
		if { $elem_type ne "Quadrilateral" } {
		    GiD_Process Mescape Meshing ElemType Triangle $surface_id
		    gid_groups_conds::setAttributesF {blockdata[@n='General data']/container[@n='Analysis']/value[@n='triang_internal_elem']} [list v $elem_type]                        
		} else {
		    GiD_Process Mescape Meshing ElemType Quadrilateral $surface_id
		    gid_groups_conds::setAttributesF {blockdata[@n='General data']/container[@n='Analysis']/value[@n='triang_internal_elem']} [list v "dkt"]                    
		}
		if { $elem_type eq "6N" } {
		    # For 6Noded trianles divide by 2 the number of divisions to obtain the same number of nodes
		    set N [expr $num/2]
		} else {
		    set N $num
		}
		
		GidUtils::Disable windows
		GidUtils::DisableGraphics
		GiD_Process Mescape Meshing Structured Surfaces $surface_id escape $N {*}$lines_list escape 0 Mescape
		if { [lindex [GiD_Info Mesh] 0] } {
		    GiD_Process Mescape Meshing CancelMesh Yes
		}
		GiD_Process Mescape Meshing Generate $N MeshingParametersFrom=Model Mescape
		set err [catch {GiD_Process Mescape Utilities Calculate} errstring]
		after 5000
		while 1 {
		    set modelName [lindex [lindex $::RunProcInfo 0] 0]
		    set uid [lindex [lindex $::RunProcInfo 0] 2]
		    if { $uid == "" } { break }
		    after 1000
		    update
		}
		GidUtils::Enable windows
		GidUtils::EnableGraphics
		
#                 set num_nodes [GiD_Info Mesh NumNodes]
#                 puts -nonewline $f "$num_nodes\t"
		puts -nonewline $f "[expr ($num+1)*($num+1)]\t"
		set timFile [file join "[GiD_Info Project ModelName].gid" debugtime]
		set total_cpu_time [getCalcTime $timFile]
		puts -nonewline $f "$total_cpu_time\t"
		
		# Postprocess
		GiD_Process Mescape Postprocess
		foreach cp $check_points {
		    lassign $cp x y z desc result result_type value max_error
		    draw_post::set_active_result $result ""
		    lassign [draw_post::give_point_information [list $x $y $z]] mesh_id num_ nodes nodes_coords p1 min_angle results GPdata    
		    puts -nonewline $f "[format "%.8f" "[expr abs($results)]"]\t"
		}                
		draw_post::end_postprocess stop
		flush $f
	    }
	}
    } errstring]

if { $err } {
    set ferr [open [file join $script_path "script.err"] w]
    puts $ferr "Script execution error: $errstring"
    flush $ferr
    after 100 [close $ferr]
}

flush $f
after 100 [close $f]











































